@@ -16,7 +16,7 @@ import subprocess
 LOGGER = logging.getLogger(__name__)
 LOG_FORMAT = ('%(levelname) -10s %(asctime)s %(name) -30s %(funcName) '
               '-35s %(lineno) -5d: %(message)s')
-LOG_LEVEL = logging.ERROR
+LOG_LEVEL = logging.WARNING
 XSAN_CONFIG_DIR = ''
 XSAN_VOLUME_CONFIG_REGEX = r'([A-Z]+)\.cfg'
 XSAN_CONFIG_NODE_REGEX = r'Node \"(.+)\" \d+'
@@ -89,11 +89,15 @@ def client_ping_response(client):
     False == client is not
 
     """
-    ping_response = subprocess.call(
-        ['/sbin/ping', '-c1', client.ip_address],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.STDOUT,
-    )
+    ping_response = -1
+    try:
+        ping_response = subprocess.call(
+            ['/sbin/ping', '-c1', client.ip_address],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+        )
+    except:
+        LOGGER.error('Error while calling /sbin/ping: %s', sys.exc_info()[0])
     return ping_response
 
 
@@ -102,91 +106,97 @@ def parse_client_io_data(client, io_data):
 
     """
     #   Getting the cvlabel data
-    cvlabels = io_data['cvlabel']
+    if 'cvlabel' in io_data:
+        cvlabels = io_data['cvlabel']
 
-    #   Clean up old cvlabels
-    all_cvlabels = models.cvlabel_entry.objects.filter(
-        host=client,
-    ).all()
-
-    for cvlabel in all_cvlabels:
-        if cvlabel.disk not in cvlabels:
-            LOGGER.info('Deleting stale record for %s', cvlabel.disk)
-            cvlabel.delete()
-
-    for cvlabel in cvlabels:
-        disk_name = cvlabel
-        cvlabel_name = cvlabels[cvlabel]
-        #   So, we either update existing cvlabel entry or create a new one
-        cvlabel_obj = models.cvlabel_entry.objects.filter(
+        #   Clean up old cvlabels
+        all_cvlabels = models.cvlabel_entry.objects.filter(
             host=client,
-            disk=disk_name,
         ).all()
 
-        if len(cvlabel_obj) == 1:
-            LOGGER.info('Updating cvlabel entry for %s', disk_name)
-            cvlabel_obj.update(
-                label=cvlabel_name
-            )
-        elif len(cvlabel_obj) == 0:
-            LOGGER.info('Creating a new cvlabel entry for %s', disk_name)
-            new_cvlabel_obj = models.cvlabel_entry(
-                host=client,
-                disk=disk_name,
-                label=cvlabel_name
-            )
-            new_cvlabel_obj.save()
-        else:
-            LOGGER.critical('Two cvlabel entries for one disk found. Something is TERRIBLY wrong!')
-            sys.exit()
+        for cvlabel in all_cvlabels:
+            if cvlabel.disk not in cvlabels:
+                LOGGER.info('Deleting stale record for %s', cvlabel.disk)
+                cvlabel.delete()
 
-    #   Getting the disk data
-    disks = io_data['iodata']
-
-    all_stat_entries = models.stat_entry.objects.filter(
-        host=client,
-    ).all()
-    for stat_entry in all_stat_entries:
-        if stat_entry.disk not in disks:
-            LOGGER.info('Deleting stale disk entry: %s', stat_entry.disk)
-            stat_entry.delete()
-
-    for disk_name in disks:
-        LOGGER.info('Updating data for %s', disk_name)
-        disk_iodata = disks[disk_name]
-
-        #   Adding a couple of auto-calculated stats
-        disk_iodata['io_sec'] = disk_iodata['io_read_sec'] + disk_iodata['io_write_sec']
-        disk_iodata['bytes_sec'] = disk_iodata['bytes_read_sec'] + disk_iodata['bytes_write_sec']
-
-        for stat in disk_iodata:
-            #   Does an entry already exist?
-            stat_type = models.stat_type.objects.filter(name=stat).all()[0]
-            stat_entry = models.stat_entry.objects.filter(
-                type=stat_type,
+        for cvlabel in cvlabels:
+            disk_name = cvlabel
+            cvlabel_name = cvlabels[cvlabel]
+            #   So, we either update existing cvlabel entry or create a new one
+            cvlabel_obj = models.cvlabel_entry.objects.filter(
                 host=client,
                 disk=disk_name,
             ).all()
 
-            stat_value = disk_iodata[stat_type.name]
-
-            if len(stat_entry) == 1:
-                LOGGER.info('Updating status entry for %s', stat_type)
-                stat_entry.update(
-                    value=stat_value
+            if len(cvlabel_obj) == 1:
+                LOGGER.info('Updating cvlabel entry for %s', disk_name)
+                cvlabel_obj.update(
+                    label=cvlabel_name
                 )
-            elif len(stat_entry) == 0:
-                LOGGER.info('Creating a new stat entry for %s', stat_type)
-                new_stat_entry = models.stat_entry(
+            elif len(cvlabel_obj) == 0:
+                LOGGER.info('Creating a new cvlabel entry for %s', disk_name)
+                new_cvlabel_obj = models.cvlabel_entry(
+                    host=client,
+                    disk=disk_name,
+                    label=cvlabel_name
+                )
+                new_cvlabel_obj.save()
+            else:
+                LOGGER.critical('Two cvlabel entries for one disk found. Something is TERRIBLY wrong!')
+                sys.exit()
+    else:
+        LOGGER.error('Response from client %s doesn\'t contain cvlabel data', client.host_name)
+
+    #   Getting the disk data
+    if 'iodata' in io_data:
+        disks = io_data['iodata']
+
+        all_stat_entries = models.stat_entry.objects.filter(
+            host=client,
+        ).all()
+        for stat_entry in all_stat_entries:
+            if stat_entry.disk not in disks:
+                LOGGER.info('Deleting stale disk entry: %s', stat_entry.disk)
+                stat_entry.delete()
+
+        for disk_name in disks:
+            LOGGER.info('Updating data for %s', disk_name)
+            disk_iodata = disks[disk_name]
+
+            #   Adding a couple of auto-calculated stats
+            disk_iodata['io_sec'] = disk_iodata['io_read_sec'] + disk_iodata['io_write_sec']
+            disk_iodata['bytes_sec'] = disk_iodata['bytes_read_sec'] + disk_iodata['bytes_write_sec']
+
+            for stat in disk_iodata:
+                #   Does an entry already exist?
+                stat_type = models.stat_type.objects.filter(name=stat).all()[0]
+                stat_entry = models.stat_entry.objects.filter(
                     type=stat_type,
                     host=client,
                     disk=disk_name,
-                    value=stat_value
-                )
-                new_stat_entry.save()
-            else:
-                LOGGER.critical('Two stat entries for one host found! This is TERRIBLY wrong!')
-                sys.exit()
+                ).all()
+
+                stat_value = disk_iodata[stat_type.name]
+
+                if len(stat_entry) == 1:
+                    LOGGER.info('Updating status entry for %s', stat_type)
+                    stat_entry.update(
+                        value=stat_value
+                    )
+                elif len(stat_entry) == 0:
+                    LOGGER.info('Creating a new stat entry for %s', stat_type)
+                    new_stat_entry = models.stat_entry(
+                        type=stat_type,
+                        host=client,
+                        disk=disk_name,
+                        value=stat_value
+                    )
+                    new_stat_entry.save()
+                else:
+                    LOGGER.critical('Two stat entries for one host found! This is TERRIBLY wrong!')
+                    sys.exit()
+    else:
+        LOGGER.error('Response from client %s does not contain disk I/O statistics', client.host_name)
 
 
 def get_stats_from_client(client):
