@@ -24,10 +24,18 @@ class display_volume_list(ListView):
 
 
 class display_volume_detail(DetailView):
+    """Get all stat entries from database and analyze them to show:
+        1) I/O stats for each client that reads/writes to LUNs of this volume only
+        2) Total I/O load on volume LUNs
+
+    """
     template_name = 'volume_detail.html'
     model = models.xsan_volume
 
     def get_context_data(self, **kwargs):
+        """Overriding the method to add client statistics into template context
+
+        """
         logging.basicConfig(level=LOG_LEVEL, format=LOG_FORMAT)
 
         # Call the base implementation first to get a context
@@ -58,20 +66,23 @@ class display_volume_detail(DetailView):
                     label=volume_lun.label
                 ).all()
                 if len(client_lun_cvlabel_entries) == 1:
-                    client_lun_cvlabel_entry = client_lun_cvlabel_entries[0]
-                    client_stat_entries = models.stat_entry.objects.filter(
-                        host=client,
-                        disk=client_lun_cvlabel_entry.disk,
-                    )
+                    for stat_type in models.stat_type.objects.all():
+                        stat_type_name = stat_type.name
+                        client_lun_cvlabel_entry = client_lun_cvlabel_entries[0]
+                        client_stat_entries = models.stat_entry.objects.filter(
+                            host=client,
+                            disk=client_lun_cvlabel_entry.disk,
+                            type=stat_type,
+                        ).latest()
 
-                    for client_stat_entry in client_stat_entries:
-                        LOGGER.info('Adding stat entry: %s', client_stat_entry.type.name)
-                        stat_type = client_stat_entry.type.name
-                        stat_value = client_stat_entry.value
-                        if stat_type in client_data:
-                            client_data[stat_type] += stat_value
-                        else:
-                            client_data[stat_type] = stat_value
+                        for client_stat_entry in client_stat_entries:
+                            #   Find the latest entry of particular type
+                            LOGGER.info('Adding stat entry: %s', client_stat_entry.type.name)
+                            stat_value = client_stat_entry.value
+                            if stat_type in client_data:
+                                client_data[stat_type_name] += stat_value
+                            else:
+                                client_data[stat_type_name] = stat_value
 
             all_clients_data.append(client_data)
 
