@@ -109,8 +109,10 @@ TEMPLATE_DIRS = (
     # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
     # Always use forward slashes, even on Windows.
     # Don't forget to use absolute paths, not relative paths.
-    os.path.join(os.curdir, 'templates').replace('\\','/'),
-    os.path.join(os.pardir, 'templates').replace('\\','/'),
+    os.path.join(
+        os.path.split(PROJECT_DIR)[0],
+        'templates',
+    )
 )
 
 INSTALLED_APPS = (
